netapp_ontap.models.volume_movement API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_movement`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeMovementSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeMovement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cutover_window GET POST PATCH`

    Time window in seconds for cutover. The allowed range is between 30 to 300 seconds.

    Example: 30

  `destination_aggregate GET POST PATCH`

    The destination_aggregate field of the volume_movement.

  `percent_complete GET`

    Completion percentage

  `state GET POST PATCH`

    State of volume move operation. PATCH the state to "aborted" to abort the move operation. PATCH the state to "cutover" to trigger cutover. PATCH the state to "paused" to pause the volume move operation in progress. PATCH the state to "replicating" to resume the paused volume move operation. PATCH the state to "cutover_wait" to go into cutover manually. When volume move operation is waiting to go into "cutover" state, this is indicated by the "cutover_pending" state. A change of state is only supported if volume movement is in progress.

    Valid choices:

    - aborted
    - cutover
    - cutover_wait
    - cutover_pending
    - failed
    - paused
    - queued
    - replicating
    - success
  `tiering_policy PATCH`

    Tiering policy for FabricPool

    Valid choices:

    - all
    - auto
    - backup
    - none
    - snapshot_only